@@ -8,7 +8,7 @@ import (
 func Airtable() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Airtable API Key",
+		Description: "Uncovered a possible Airtable API Key, potentially compromising database access and leading to data leakage or alteration.",
 		RuleID:      "airtable-api-key",
 		Regex:       generateSemiGenericRegex([]string{"airtable"}, alphaNumeric("17"), true),
 		Keywords:    []string{"airtable"},
