@@ -8,7 +8,7 @@ import (
 func Atlassian() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Atlassian API token",
+		Description: "Detected an Atlassian API token, posing a threat to project management and collaboration tool security and data confidentiality.",
 		RuleID:      "atlassian-api-token",
 		Regex: generateSemiGenericRegex([]string{
 			"atlassian", "confluence", "jira"}, alphaNumeric("24"), true),
