@@ -10,7 +10,7 @@ import (
 func PyPiUploadToken() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "PyPI upload token",
+		Description: "Discovered a PyPI upload token, potentially compromising Python package distribution and repository integrity.",
 		RuleID:      "pypi-upload-token",
 		Regex: regexp.MustCompile(
 			`pypi-AgEIcHlwaS5vcmc[A-Za-z0-9\-_]{50,1000}`),
