@@ -9,7 +9,7 @@ import (
 func SidekiqSecret() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Sidekiq Secret",
+		Description: "Discovered a Sidekiq Secret, which could lead to compromised background job processing and application data breaches.",
 		RuleID:      "sidekiq-secret",
 
 		Regex: generateSemiGenericRegex([]string{"BUNDLE_ENTERPRISE__CONTRIBSYS__COM", "BUNDLE_GEMS__CONTRIBSYS__COM"},
@@ -34,7 +34,7 @@ func SidekiqSecret() *config.Rule {
 func SidekiqSensitiveUrl() *config.Rule {
 	// define rule
 	r := config.Rule{
-		Description: "Sidekiq Sensitive URL",
+		Description: "Uncovered a Sidekiq Sensitive URL, potentially exposing internal job queues and sensitive operation details.",
 		RuleID:      "sidekiq-sensitive-url",
 		SecretGroup: 2,
 		Regex:       regexp.MustCompile(`(?i)\b(http(?:s??):\/\/)([a-f0-9]{8}:[a-f0-9]{8})@(?:gems.contribsys.com|enterprise.contribsys.com)(?:[\/|\#|\?|:]|$)`),
