@@ -9,7 +9,7 @@ func Typeform() *config.Rule {
 	// define rule
 	r := config.Rule{
 		RuleID:      "typeform-api-token",
-		Description: "Typeform API token",
+		Description: "Uncovered a Typeform API token, which could lead to unauthorized survey management and data collection.",
 		Regex: generateSemiGenericRegex([]string{"typeform"},
 			`tfp_[a-z0-9\-_\.=]{59}`, true),
 		Keywords: []string{
